==> TencentNavKitDocument_7.1.1.zip: TencentNavKitDocument/interface_t_n_k_base_nav_view.js <==
var interface_t_n_k_base_nav_view =
[
    [ "clearAllRouteUI", "interface_t_n_k_base_nav_view.html#a0e28be6fec7da6cb3d86d267183bc5cb", null ],
    [ "configureUserLocationPresentation:", "interface_t_n_k_base_nav_view.html#af31d40e59355fbe4563777650acb0fb5", null ],
    [ "initWithFrame:config:", "interface_t_n_k_base_nav_view.html#a07e750196ff07710e17e0a38e1176092", null ],
    [ "setMapStyle:", "interface_t_n_k_base_nav_view.html#a1dd5c15f6cf02b8da4a9aee650eb867c", null ],
    [ "UNAVAILABLE_ATTRIBUTE", "interface_t_n_k_base_nav_view.html#ac43abee626665d295ffdb6f1cbc8bd7c", null ],
    [ "updateDestinationMarkerPresentation:", "interface_t_n_k_base_nav_view.html#a63974033cb83f23fb5118ec24cc49e51", null ],
    [ "updateOriginMarkerPresentation:", "interface_t_n_k_base_nav_view.html#af56ca56d0b2aad2f13fafe6be84cf735", null ],
    [ "updateRedLineConfig:", "interface_t_n_k_base_nav_view.html#a255a95795ce370325d14191117644c48", null ],
    [ "updateRouteConfig:", "interface_t_n_k_base_nav_view.html#af2fef5a54f4b50ec32341564cdd3adf1", null ],
    [ "updateUserLocationPresentation:", "interface_t_n_k_base_nav_view.html#a4664f514257ab13681563011496c8f3f", null ],
    [ "compassHidden", "interface_t_n_k_base_nav_view.html#a815c71931246bc745a52291e48e4ca67", null ],
    [ "dayNightMode", "interface_t_n_k_base_nav_view.html#a97b1c7cb22960aa6d17f3c34fac0471f", null ],
    [ "dayNightStatus", "interface_t_n_k_base_nav_view.html#a186ac565d4cee9816c3a57a0622a4c07", null ],
    [ "externalEdgeInsets", "interface_t_n_k_base_nav_view.html#a2fe8e155791b9842f57c6a885994af58", null ],
    [ "extraPointsForOverview", "interface_t_n_k_base_nav_view.html#a8c395e16f20f56ea0a8b049cc6136c94", null ],
    [ "fix2DProportion", "interface_t_n_k_base_nav_view.html#a5e35454fc1d64056dc04fda55026cd3c", null ],
    [ "fix3DProportion", "interface_t_n_k_base_nav_view.html#a421e780827f7d426dbd4a2992c9c747e", null ],
    [ "followDelay", "interface_t_n_k_base_nav_view.html#ac5ba49ac3545c9142030e0f1a065db2a", null ],
    [ "followed", "interface_t_n_k_base_nav_view.html#a2ec28ad2b4b658ccf9c2c72ce1144553", null ],
    [ "followEnabled", "interface_t_n_k_base_nav_view.html#aac3243274a394dd1d53a49c8e12eb51a", null ],
    [ "mapView", "interface_t_n_k_base_nav_view.html#a9eef5c990eeb1fcad50bf790b05092bd", null ],
    [ "navUIMode", "interface_t_n_k_base_nav_view.html#aedc7298a8e0135d290a39f8fb7ff1247", null ],
    [ "nonOverviewNaviUIMode", "interface_t_n_k_base_nav_view.html#ac2e496a3836fa78f76ae0d784e790f26", null ],
    [ "overviewNaviUIMode", "interface_t_n_k_base_nav_view.html#a0285c8dad53420cfbbff0ada4fd5ddc3", null ],
    [ "routeConfig", "interface_t_n_k_base_nav_view.html#a61b3e83fb59d47a933033e93219cb14d", null ],
    [ "showsUserLocation", "interface_t_n_k_base_nav_view.html#a04809a6d330a2563b263a313d0a60311", null ],
    [ "turnArrowConfig", "interface_t_n_k_base_nav_view.html#abbf9b3753705fbb2dc2ead2ecdc8d892", null ],
    [ "turnArrowEnabled", "interface_t_n_k_base_nav_view.html#a23bf3cafd5fe813e42a698964d8cf5ea", null ]
];

==> TencentNavKitDocument_7.2.0.zip: TencentNavKitDocument/interface_t_n_k_base_nav_view.js <==
var interface_t_n_k_base_nav_view =
[
    [ "clearAllRouteUI", "interface_t_n_k_base_nav_view.html#a0e28be6fec7da6cb3d86d267183bc5cb", null ],
    [ "configureUserLocationPresentation:", "interface_t_n_k_base_nav_view.html#af31d40e59355fbe4563777650acb0fb5", null ],
    [ "initWithFrame:config:", "interface_t_n_k_base_nav_view.html#a07e750196ff07710e17e0a38e1176092", null ],
    [ "setMapStyle:", "interface_t_n_k_base_nav_view.html#a1dd5c15f6cf02b8da4a9aee650eb867c", null ],
    [ "UNAVAILABLE_ATTRIBUTE", "interface_t_n_k_base_nav_view.html#ac43abee626665d295ffdb6f1cbc8bd7c", null ],
    [ "updateDestinationMarkerPresentation:", "interface_t_n_k_base_nav_view.html#a63974033cb83f23fb5118ec24cc49e51", null ],
    [ "updateOriginMarkerPresentation:", "interface_t_n_k_base_nav_view.html#af56ca56d0b2aad2f13fafe6be84cf735", null ],
    [ "updateRedLineConfig:", "interface_t_n_k_base_nav_view.html#a255a95795ce370325d14191117644c48", null ],
    [ "updateRouteConfig:", "interface_t_n_k_base_nav_view.html#af2fef5a54f4b50ec32341564cdd3adf1", null ],
    [ "updateUserLocationPresentation:", "interface_t_n_k_base_nav_view.html#a4664f514257ab13681563011496c8f3f", null ],
    [ "compassHidden", "interface_t_n_k_base_nav_view.html#a815c71931246bc745a52291e48e4ca67", null ],
    [ "dayNightMode", "interface_t_n_k_base_nav_view.html#a97b1c7cb22960aa6d17f3c34fac0471f", null ],
    [ "dayNightStatus", "interface_t_n_k_base_nav_view.html#a186ac565d4cee9816c3a57a0622a4c07", null ],
    [ "exitOverviewDelay", "interface_t_n_k_base_nav_view.html#a68ef966e41f2efb6da4f004b828b7366", null ],
    [ "exitOverviewEnabled", "interface_t_n_k_base_nav_view.html#abccefd380cde4b22232927f3d4718daa", null ],
    [ "externalEdgeInsets", "interface_t_n_k_base_nav_view.html#a2fe8e155791b9842f57c6a885994af58", null ],
    [ "extraPointsForOverview", "interface_t_n_k_base_nav_view.html#a8c395e16f20f56ea0a8b049cc6136c94", null ],
    [ "fix2DProportion", "interface_t_n_k_base_nav_view.html#a5e35454fc1d64056dc04fda55026cd3c", null ],
    [ "fix3DProportion", "interface_t_n_k_base_nav_view.html#a421e780827f7d426dbd4a2992c9c747e", null ],
    [ "followDelay", "interface_t_n_k_base_nav_view.html#ac5ba49ac3545c9142030e0f1a065db2a", null ],
    [ "followed", "interface_t_n_k_base_nav_view.html#a2ec28ad2b4b658ccf9c2c72ce1144553", null ],
    [ "followEnabled", "interface_t_n_k_base_nav_view.html#aac3243274a394dd1d53a49c8e12eb51a", null ],
    [ "mapView", "interface_t_n_k_base_nav_view.html#a9eef5c990eeb1fcad50bf790b05092bd", null ],
    [ "navUIMode", "interface_t_n_k_base_nav_view.html#aedc7298a8e0135d290a39f8fb7ff1247", null ],
    [ "nonOverviewNaviUIMode", "interface_t_n_k_base_nav_view.html#ac2e496a3836fa78f76ae0d784e790f26", null ],
    [ "overviewNaviUIMode", "interface_t_n_k_base_nav_view.html#a0285c8dad53420cfbbff0ada4fd5ddc3", null ],
    [ "routeConfig", "interface_t_n_k_base_nav_view.html#a61b3e83fb59d47a933033e93219cb14d", null ],
    [ "showsUserLocation", "interface_t_n_k_base_nav_view.html#a04809a6d330a2563b263a313d0a60311", null ],
    [ "turnArrowConfig", "interface_t_n_k_base_nav_view.html#abbf9b3753705fbb2dc2ead2ecdc8d892", null ],
    [ "turnArrowEnabled", "interface_t_n_k_base_nav_view.html#a23bf3cafd5fe813e42a698964d8cf5ea", null ]
];
